"""Development settings and globals."""

from __future__ import absolute_import


from os.path import join
from os.path import normpath
from os import environ



# Normally you should not import ANYTHING from Django directly
# into your settings, but ImproperlyConfigured is an exception.
from django.core.exceptions import ImproperlyConfigured


def get_env_setting(key):
    """
    Get the environment setting or return exception,
    if default is not set

    :param key:
    """
    try:
        return environ[key]
    except KeyError:
        error_msg = 'Set the {0} env variable'.format(key)
        raise ImproperlyConfigured(error_msg)

# ######### DEBUG CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#debug
DEBUG = True
########## END DEBUG CONFIGURATION

########## SITE CONFIGURATION
# Hosts/domain names that are valid for this site
# See: https://docs.djangoproject.com/en/dev/ref/settings/#allowed-hosts
ALLOWED_HOSTS = [
    '*'
]
########## END SITE CONFIGURATION



#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
- rest_pyotp.models
~~~~~~~~~~~~~~

- This file holds the necessary models for pyotp service
"""

# future
from __future__ import unicode_literals

# 3rd party
import uuid

# Django
from django.db import models

try:
    from django.utils.translation import ugettext_lazy as _
except:
    from django.utils.translation import gettext_lazy as _  # Django 4 version support
# local


# own app


class PyOTP(models.Model):
    """pyotp model

        Here we will store secret of every generated otp. So that on verification of OTP we know which secret to use
    """

    # Attributes
    uuid = models.UUIDField(
            _('OTP Unique uuid'),
            unique=True,
            default=uuid.uuid4,
            editable=False,
            help_text=_('Non-editable, to be generated by system itself.'),
    )
    secret = models.CharField(
            _('Secret'),
            null=False,
            blank=False,
            max_length=50,
            help_text=_('Secret used to generate OTP.'),
    )
    count = models.IntegerField(
            _('Count'),
            null=True,
            blank=True,
            help_text=_('OTP Count, to be used in case of HOTP.'),
    )
    interval = models.IntegerField(
            _('Interval (in seconds)'),
            null=True,
            blank=True,
            help_text=_('OTP Count, to be used in case of TOTP.'),
    )
    otp = models.CharField(
            _('OTP'),
            null=False,
            blank=False,
            max_length=10,
            help_text=_('Generated OTP.'),
    )
    name = models.CharField(
            _('Account Name'),
            null=True,
            blank=True,
            max_length=255,
            help_text=_('Account Name for Provisioning URI, to be used when need URI for QR code.'),
    )
    initial_count = models.IntegerField(
            _('Initial Count'),
            null=True,
            blank=True,
            help_text=_('Initial Count for Provisioning URI.'),
    )
    issuer_name = models.CharField(
            _('Issuer Name'),
            null=True,
            blank=True,
            max_length=255,
            help_text=_('Issuer Name for Provisioning URI.'),
    )
    created_at = models.DateTimeField(
                 _('created at'),
                 auto_now_add=True,
                 db_index=True,
    )

    # Meta
    class Meta:
        verbose_name = _("PyOtp")
        verbose_name_plural = _("PyOtp")

    # Functions
    def __str__(self):
        return str(self.uuid)



#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
- rest_pyotp.admin
~~~~~~~~~~~~~~

- This file contains admin models of pyotp app
"""

# future
from __future__ import unicode_literals

# 3rd party

# Django
from django.contrib import admin

# local

# own app
from rest_pyotp import models


class PyOTPAdmin(admin.ModelAdmin):
    """
    """
    list_display = ('id', 'uuid', 'secret', 'count', 'interval', 'otp', 'created_at',)
    list_display_links = ('uuid',)
    search_fields = ('uuid', 'secret', 'otp', )
    list_per_page = 20
    ordering = ('-id',)

admin.site.register(models.PyOTP, PyOTPAdmin)





"""Common settings and globals."""
from __future__ import absolute_import

from os.path import abspath
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import normpath
from os import environ

from sys import path

# Normally you should not import ANYTHING from Django directly
# into your settings, but ImproperlyConfigured is an exception.
from django.core.exceptions import ImproperlyConfigured


def get_env_setting(key):
    """
    Get the environment setting or return exception,
    if default is not set

    :param key:
    """
    try:
        return environ[key]
    except KeyError:
        error_msg = 'Set the {0} env variable'.format(key)
        raise ImproperlyConfigured(error_msg)


# ######### PATH CONFIGURATION
# Absolute filesystem path to the Django project directory:
DJANGO_ROOT = dirname(abspath(__file__))

# Site name:
SITE_NAME = basename(DJANGO_ROOT)

# Absolute filesystem path to the top-level project folder:
SITE_ROOT = dirname(DJANGO_ROOT)

# Site sub-module name:
SITE_MODULE = basename(DJANGO_ROOT)

# Add our project to our pythonpath, this way we don't need to type our project
# name in our dotted import paths:
path.append(DJANGO_ROOT)
# ######### END PATH CONFIGURATION


# ######### DEBUG CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#debug
DEBUG = False
# ######### END DEBUG CONFIGURATION


# ######### TEST RUNNER CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/releases/dev/#new-test-runner
TEST_RUNNER = 'django.test.runner.DiscoverRunner'
# ######### END TEST RUNNER CONFIGURATION


# ######### MANAGER CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#admins
ADMINS = (
)

# See: https://docs.djangoproject.com/en/dev/ref/settings/#managers
MANAGERS = (
)
# ######### END MANAGER CONFIGURATION


# ######### DATABASE CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#databases
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': 'db.sqlite3',
    }
}
# ######### END DATABASE CONFIGURATION


# ######### ATOMICITY CONFIGURATION
# https://docs.djangoproject.com/en/dev/ref/settings/#std:setting-DATABASE-ATOMIC_REQUESTS
ATOMIC_REQUESTS = True
# ######### END ATOMICITY CONFIGURATION


# ######### GENERAL CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#time-zone
TIME_ZONE = 'UTC'

# See: https://docs.djangoproject.com/en/dev/ref/settings/#datetime-format
DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S%z'

# See: https://docs.djangoproject.com/en/dev/ref/settings/#date-format
DATE_FORMAT = 'N j, Y'

# See: https://docs.djangoproject.com/en/dev/ref/settings/#time-format
TIME_FORMAT = 'P'

# See: https://docs.djangoproject.com/en/dev/ref/settings/#language-code
LANGUAGE_CODE = 'en-us'

# See: https://docs.djangoproject.com/en/dev/ref/settings/#site-id
SITE_ID = 1

# See: https://docs.djangoproject.com/en/dev/ref/settings/#use-i18n
USE_I18N = True

# See: https://docs.djangoproject.com/en/dev/ref/settings/#use-l10n
USE_L10N = True

# See: https://docs.djangoproject.com/en/dev/ref/settings/#use-tz
USE_TZ = True

LOCALE_PATHS = (
    join(SITE_ROOT, 'locale'),
)
# ######### END GENERAL CONFIGURATION


# ######### MEDIA CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#media-root
MEDIA_ROOT = normpath(join(SITE_ROOT, 'media'))

# See: https://docs.djangoproject.com/en/dev/ref/settings/#media-url
MEDIA_URL = '/media/'
# ######### END MEDIA CONFIGURATION


# ######### STATIC FILE CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#static-root
STATIC_ROOT = normpath(join(SITE_ROOT, 'assets'))

# See: https://docs.djangoproject.com/en/dev/ref/settings/#static-url
STATIC_URL = '/static/'

# See: https://docs.djangoproject.com/en/dev/ref/contrib/staticfiles/#std:setting-STATICFILES_DIRS
STATICFILES_DIRS = (
    normpath(join(SITE_ROOT, 'static')),
)

# See: https://docs.djangoproject.com/en/dev/ref/contrib/staticfiles/#staticfiles-finders
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'django.contrib.staticfiles.finders.FileSystemFinder',
)
# ######### END STATIC FILE CONFIGURATION

# ######### SITE CONFIGURATION
# Hosts/domain names that are valid for this site
# See: https://docs.djangoproject.com/en/dev/ref/settings/#allowed-hosts
ALLOWED_HOSTS = []
# ######### END SITE CONFIGURATION

# ######### SECRET CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#secret-key
# Note: This key should only be used for development and testing.
SECRET_KEY = get_env_setting('SECRET_KEY')
# ######### END SECRET CONFIGURATION

# ######### FIXTURE CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#std:setting-FIXTURE_DIRS
FIXTURE_DIRS = (
    normpath(join(SITE_ROOT, 'fixtures')),
)
# ######### END FIXTURE CONFIGURATION


# ######### TEMPLATE CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#std:setting-TEMPLATES
TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            'templates'
        ],
        'APP_DIRS': True,
        'OPTIONS': {
            'debug': DEBUG,
            'context_processors': [
                'django.template.context_processors.request',
                'django.template.context_processors.static',
                'django.contrib.auth.context_processors.auth',
                'django.template.context_processors.request',
            ]
        }
    }
]
# ######### END TEMPLATE CONFIGURATION


# ######### MIDDLEWARE CONFIGURATION
# See: https://docs.djangoproject.com/en/1.10/ref/settings/#std:setting-MIDDLEWARE
MIDDLEWARE = [
    # Default Django middleware.
    # 'django.middleware.cache.UpdateCacheMiddleware',
    # 'reversion.middleware.RevisionMiddleware',

    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    # 'django.middleware.cache.FetchFromCacheMiddleware'
]
# ######### END MIDDLEWARE CONFIGURATION


# ######### URL CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#root-urlconf
ROOT_URLCONF = '{0}.urls'.format(SITE_MODULE)
# ######### END URL CONFIGURATION


# ######### APP CONFIGURATION
DJANGO_APPS = (
    # Default Django apps:
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin'
    # Useful template tags:
    # 'django.contrib.humanize'
)

THIRD_PARTY_APPS = (
    'rest_framework',
    'rest_framework_swagger',
)

# Apps specific for this project go here.
LOCAL_APPS = (
    'rest_pyotp',
)

# See: https://docs.djangoproject.com/en/dev/ref/settings/#installed-apps
INSTALLED_APPS = DJANGO_APPS + THIRD_PARTY_APPS + LOCAL_APPS
# ######### END APP CONFIGURATION


# ######### WSGI CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#wsgi-application
WSGI_APPLICATION = '{0}.wsgi.application'.format(SITE_MODULE)
# ######### END WSGI CONFIGURATION


# ######### PASSWORD VALIDATION CONFIGURATION
# See: https://docs.djangoproject.com/en/1.10/topics/auth/passwords/#password-validation
AUTH_PASSWORD_VALIDATORS = [
    {'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator'},
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
        'OPTIONS': {
            'min_length': 4,
        }
    },
    {'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator'},
    {'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator'},
]
# ######### END PASSWORD VALIDATION CONFIGURATION


# ######### PASSWORD HASHER CONFIGURATION
# See: https://docs.djangoproject.com/en/1.10/topics/auth/passwords/#password-validation
# Argon2 is the winner of the 2015 Password Hashing Competition,
# a community organized open competition to select a next generation hashing algorithm.
# It's designed not to be easier to compute on custom hardware than it is to compute on an ordinary CPU.
# Argon2 is not the default for Django because it requires a third-party library.
# The Password Hashing Competition panel, however, recommends immediate use of Argon2 rather
# than the other algorithms supported by Django.
PASSWORD_HASHERS = [
    'django.contrib.auth.hashers.Argon2PasswordHasher',
    'django.contrib.auth.hashers.PBKDF2PasswordHasher',
    'django.contrib.auth.hashers.PBKDF2SHA1PasswordHasher',
    'django.contrib.auth.hashers.BCryptSHA256PasswordHasher',
    'django.contrib.auth.hashers.BCryptPasswordHasher'
]
# ######### END PASSWORD HASHER CONFIGURATION


# ######### DJANGO REST FRAMEWORK CONFIGURATION
REST_FRAMEWORK = {
    # Use Django's standard `django.contrib.auth` permissions,
    # or allow read-only access for unauthenticated users.
    'DEFAULT_RENDERER_CLASSES': [
        'rest_framework.renderers.JSONRenderer',
        'rest_framework.renderers.BrowsableAPIRenderer',
        'rest_framework.renderers.CoreJSONRenderer',

        'rest_framework_swagger.renderers.OpenAPIRenderer',
        'rest_framework_swagger.renderers.SwaggerUIRenderer',
    ],
    'DEFAULT_PERMISSION_CLASSES': [
        'rest_framework.permissions.AllowAny',
    ],
    'DEFAULT_AUTHENTICATION_CLASSES': (
        'rest_framework.authentication.TokenAuthentication',
        'rest_framework.authentication.BasicAuthentication',
        'rest_framework.authentication.SessionAuthentication',
    ),
    'DEFAULT_FILTER_BACKENDS': (
        'rest_framework.filters.OrderingFilter',
        'rest_framework.filters.SearchFilter'
    ),
    'DEFAULT_PAGINATION_CLASS': 'rest_framework.pagination.LimitOffsetPagination',
    'PAGE_SIZE': 50
}
# ######### END DJANGO REST FRAMEWORK CONFIGURATION

try:
    from .local import *
except Exception as e:
    print (e)



#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
- rest_pyotp.views
~~~~~~~~~~~

- This file contains API's for rest_pyotp
"""

# future
from __future__ import unicode_literals

# 3rd party

# rest-framework
from rest_framework import viewsets, status
from rest_framework.response import Response

# Django

# local

# own app
from rest_pyotp import serializers, models


class PyotpViewset(viewsets.GenericViewSet):
    """Pyotp Viewset, every pyotp http request handles by this class

    """
    queryset = models.PyOTP.objects.all()
    lookup_field = 'uuid'
    otp_type = None

    def get_serializer_class(self):
        if self.action == 'generate_hotp':
            return serializers.HotpSerializer
        elif self.action == 'generate_totp':
            return serializers.TotpSerializer
        elif self.action == 'generate_hotp_provision_uri':
            return serializers.HOTPProvisionUriSerializer
        elif self.action == 'generate_totp_provision_uri':
            return serializers.TOTPProvisionUriSerializer
        elif self.action == 'verify_otp':
            return serializers.VerifyOtpSerilaizer
        return serializers.NoneSerializer

    def _validate(self, serializer, data):
        """
        :param serializer: serializer against which data to ve validated
        :param data: data to ve validated
        :return: serializer instance.
        """

        serializer_instance = serializer(data=data)
        serializer_instance.is_valid(raise_exception=True)
        return serializer_instance.save()

    def generate_hotp(self, request):
        """
        """
        serializer = self.get_serializer_class()
        serializer = self._validate(serializer, request.data)

        return Response(serializer, status=status.HTTP_201_CREATED)

    def generate_totp(self, request):
        """
        """
        serializer = self.get_serializer_class()
        serializer = self._validate(serializer, request.data)
        return Response(serializer, status=status.HTTP_201_CREATED)

    def generate_hotp_provision_uri(self, request):
        """
        """
        serializer = self.get_serializer_class()
        serializer = self._validate(serializer, request.data)

        return Response(serializer, status=status.HTTP_201_CREATED)

    def generate_totp_provision_uri(self, request):
        """
        """
        serializer = self.get_serializer_class()
        serializer = self._validate(serializer, request.data)
        
        return Response(serializer, status=status.HTTP_201_CREATED)

    def verify_otp(self, request, otp_type, uuid):
        """

        :param request: Django request
        :param otp_type: otp_type  [hotp/totp]
        :param uuid: OTP instance UUID
        :return: 200_ok OR 400_bad_request
        """
        obj = self.get_object()
        serializer = self.get_serializer_class()

        serializer = serializer(data=request.data)
        serializer.is_valid(raise_exception=True)

        valid_otp = serializer.verify_otp(serializer.data.get('otp'), obj, otp_type)
        if not valid_otp:
            return Response(status=status.HTTP_400_BAD_REQUEST)
        return Response(status=status.HTTP_200_OK)







#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
- rest_pyotp.mixins
~~~~~~~~~~~~~~

- This file includes custom mixins to customize Behaviour of any existing class
"""

# future
from __future__ import unicode_literals

# 3rd party
import pyotp

# Django

# local

# own app
from rest_pyotp.models import PyOTP


class OTPMixin(object):
    """
    Apply this mixin to Perform Various operations of PyOTP.
    """
    provision_uri = False

    def _get_random_base32_string(self):
        """Generate Random Base32 string

        """
        return pyotp.random_base32()

    def _insert_into_db(self, otp, secret=None, count=None, interval=None, data={}):
        """

        :param secret: otp secret.
        :param count: hotp count.
        :param interval: totp interval
        :param data: other data (related to provisioning uri)
        :return: otp object
        """
        fields = {
            'otp': otp,
            'secret': secret,
            'count': count,
            'interval': interval
        }

        # is provision settings is True only then save data into db
        if self.provision_uri is True:
            fields.update(**data)

        return PyOTP.objects.create(**fields)

    def _generate_hotp(self, count, provision_uri=False, data={}):
        """Generates counter-based OTPs

        """
        self.provision_uri = provision_uri
        base32string = self._get_random_base32_string()
        hotp = pyotp.HOTP(base32string)
        otp = hotp.at(count)

        # save data into db
        obj = self._insert_into_db(otp, secret=base32string, count=count, data=data)
        return self._create_response(otp, obj, hotp, data)

    def _generate_totp(self, interval, provision_uri=False, data={}):
        """Generates time-based OTPs

        """
        self.provision_uri = provision_uri
        base32string = self._get_random_base32_string()
        totp = pyotp.TOTP(base32string, interval=interval)
        otp = totp.now()

        # save data into db
        obj = self._insert_into_db(otp, secret=base32string, interval=interval, data=data)
        return self._create_response(otp, obj, totp, data)

    def _create_response(self, otp, instance, otp_type_obj, data):
        """Create Response

        :param instance: pytop model instance
        :param otp_type_obj: hotp/totp object
        :param data: other data (related to provisioning uri)
        :return: response dict
        """
        response = {
            'otp_uuid': str(instance.uuid),
            'otp': otp
        }

        # Generate provision uri if settings is True
        if self.provision_uri is True:
            provisioning_uri = otp_type_obj.provisioning_uri(**data)
            response = {
                'provisioning_uri': provisioning_uri
            }

        return response



#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
- rest_pyotp.serializer
~~~~~~~~~~~~~~

- This file contains pyotp app serializers
"""

# future
from __future__ import unicode_literals

# 3rd party
import pyotp

# DRF
from rest_framework import serializers

# Django

# local

# own app
from rest_pyotp import mixins


class NoneSerializer(serializers.Serializer):
    pass


class TotpSerializer(mixins.OTPMixin, serializers.Serializer):
    """TOTP serializer

    """
    time = serializers.IntegerField(required=True, help_text="OTP Validity-Time (in seconds).")

    def create(self, validated_data):
        """

        :param validated_data: valid data
        :return: pyotp object
        """
        interval = validated_data.pop('time')
        return self._generate_totp(interval, data=validated_data)


class HotpSerializer(mixins.OTPMixin, serializers.Serializer):
    """HOTP serializer

    """
    count = serializers.IntegerField(required=True, help_text="OTP Counter.")

    def create(self, validated_data):
        """

        :param validated_data: valid data
        :return: pyotp object
        """
        count = validated_data.pop('count')
        return self._generate_hotp(count, data=validated_data)


class ProvisionUriSerializer(serializers.Serializer):
    """Serializer for provisioning serializer.

    """
    name = serializers.CharField(required=True, help_text="name of the account")
    issuer_name = serializers.CharField(help_text="name of the OTP issuer")


class TOTPProvisionUriSerializer(TotpSerializer, ProvisionUriSerializer):
    """Serializer for provisioning serializer + TOTP.

    """

    def create(self, validated_data):
        """

        :param validated_data: valid data
        :return: pyotp object
        """
        interval = validated_data.pop('time')
        return self._generate_totp(
            interval, provision_uri=True, data=validated_data)


class HOTPProvisionUriSerializer(HotpSerializer, ProvisionUriSerializer):
    """Serializer for provisioning serializer + HOTP.

    """
    initial_count = serializers.CharField(default=0, help_text="starting counter value, defaults to 0")

    def create(self, validated_data):
        """

        :param validated_data: valid data
        :return: pyotp object
        """
        count = validated_data.pop('count')
        return self._generate_hotp(count, provision_uri=True, data=validated_data)


class VerifyOtpSerilaizer(serializers.Serializer):
    """Serializer used to verify OTP

    """
    otp = serializers.CharField(required=True)

    def verify_otp(self, otp, obj, otp_type):
        """

        :param otp_type:
        :return:
        """
        if otp_type == 'hotp' and obj.count:
            hotp = pyotp.HOTP(obj.secret)
            return hotp.verify(otp, obj.count)
        elif otp_type == 'totp' and obj.interval:
            totp = pyotp.TOTP(obj.secret, interval=obj.interval)
            return totp.verify(otp)
        return False



#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
- pyotp.routers
~~~~~~~~~~~~~~

- This file contains pyotp routers
"""

# future
from __future__ import unicode_literals

# 3rd party


# Django
from django.conf.urls import url

# local

# own app
from rest_pyotp import views


UUID_REGEX = '[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}'
OTP_TYPE_REGEX = '(hotp|totp)'

verify_otp = views.PyotpViewset.as_view({
    'post': 'verify_otp',
})

generate_hotp = views.PyotpViewset.as_view({
    'post': 'generate_hotp',
})

generate_totp = views.PyotpViewset.as_view({
    'post': 'generate_totp',
})

generate_hotp_provision_uri = views.PyotpViewset.as_view({
    'post': 'generate_hotp_provision_uri',
})

generate_totp_provision_uri = views.PyotpViewset.as_view({
    'post': 'generate_totp_provision_uri',
})

urlpatterns = [
    url(r'^generate-otp/hotp/$',
        generate_hotp,
        name='generate-hotp'),
    url(r'^generate-otp/totp/$',
        generate_totp,
        name='generate-totp'),
    url(r'^generate-otp/hotp/provision-uri/$',
        generate_hotp_provision_uri,
        name='generate-totp-provision-uri'),
    url(r'^generate-otp/totp/provision-uri/$',
        generate_totp_provision_uri,
        name='generate-totp-provision-uri'),
    url(r'^verify-otp/(?P<otp_type>(hotp|totp))/(?P<uuid>{uuid})/$'.format(otp_type=OTP_TYPE_REGEX, uuid=UUID_REGEX),
        verify_otp,
        name='verify-otp'),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-02 07:13
from __future__ import unicode_literals

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='PyOTP',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, help_text='Non-editable, to be generated by system itself.', unique=True, verbose_name='OTP Unique uuid')),
                ('secret', models.CharField(help_text='Secret used to generate OTP.', max_length=50, verbose_name='Secret')),
                ('count', models.IntegerField(blank=True, help_text='OTP Count, to be used in case of HOTP.', null=True, verbose_name='Count')),
                ('interval', models.IntegerField(blank=True, help_text='OTP Count, to be used in case of TOTP.', null=True, verbose_name='Interval (in seconds)')),
                ('otp', models.CharField(help_text='Generated OTP.', max_length=10, verbose_name='OTP')),
                ('name', models.CharField(blank=True, help_text='Account Name for Provisioning URI, to be used when need URI for QR code.', max_length=255, null=True, verbose_name='Account Name')),
                ('initial_count', models.IntegerField(blank=True, help_text='Initial Count for Provisioning URI.', null=True, verbose_name='Initial Count')),
                ('issuer_name', models.CharField(blank=True, help_text='Issuer Name for Provisioning URI.', max_length=255, null=True, verbose_name='Issuer Name')),
                ('created_at', models.DateTimeField(auto_now_add=True, db_index=True, verbose_name='created at')),
            ],
            options={
                'verbose_name': 'PyOtp',
                'verbose_name_plural': 'PyOtp',
            },
        ),
    ]



from distutils.core import setup
from setuptools import find_packages

setup(
  name='drf-pyotp',
  packages=find_packages(exclude=['example']),
  version='0.5.7',
  description='Rest extension of PyOTP python library, Here OTP generation and Verification is done via DRF APIs.',
  author='Neeraj Dhiman',
  author_email='ndhiman08@gmail.com',
  license='GPL',
  url='https://github.com/inforian/drf-pyotp',
  download_url='https://github.com/inforian/drf-pyotp/archive/v0.5.5.tar.gz',
  keywords=['otp', 'pyotp', 'totp', 'hotp', 'drf-pyotp'],
  classifiers=[],
  install_requires=[
    'Django>=1.9',
    'djangorestframework>=3.0',
    'pyotp>=2.2.4',
  ]
)
